Bug class

Constructors

Bug({required String id, required String projectId, required String title, required String description, required String status, required BugSeverity severity, String? stepsToReproduce, required DeviceInfo deviceInfo, required String createdAt})
const
Bug.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt String
final
description String
final
deviceInfo DeviceInfo
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity BugSeverity
final
status String
final
stepsToReproduce String?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited