DeviceInfo class

Constructors

DeviceInfo({required String platform, required String osVersion, required String deviceModel, required String appVersion, required String appBuildNumber, required String sdkVersion})
const
DeviceInfo.fromJson(Map<String, dynamic> json)
factory

Properties

appBuildNumber String
final
appVersion String
final
deviceModel String
final
hashCode int
The hash code for this object.
no setterinherited
osVersion String
final
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkVersion String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

collect({required String appVersion, required String appBuildNumber}) Future<DeviceInfo>