Feedback class

Constructors

Feedback({required String id, required String projectId, required String title, required String description, required String status, String? category, required int voteCount, required String createdAt, required String updatedAt})
const
Feedback.fromJson(Map<String, dynamic> json)
factory

Properties

category String?
final
createdAt String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
title String
final
updatedAt String
final
voteCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited