RoadmapItem class

Constructors

RoadmapItem({required String id, required String title, required String description, required String status, required String priority, String? estimatedDate, String? completedDate, required List<String> feedbackIds})
const
RoadmapItem.fromJson(Map<String, dynamic> json)
factory

Properties

completedDate String?
final
description String
final
estimatedDate String?
final
feedbackIds List<String>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
priority String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited