Northlight class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
configure(
String apiKey) → Future< void> - Configure the SDK with your API key
-
getPublicFeedback(
) → Future< List< Feedback> > - Get list of public feedback
-
getRoadmap(
) → Future< List< RoadmapItem> > - Get roadmap items
-
presentBugReportView(
) → Future< void> - Present the bug report view
-
presentFeedbackView(
) → Future< void> - Present the feedback form view
-
presentPublicFeedbackView(
) → Future< void> - Present the public feedback list view
-
presentRoadmapView(
) → Future< void> - Present the roadmap view
-
reportBug(
{required String title, required String description, required BugSeverity severity, String? stepsToReproduce}) → Future< String> - Report a bug programmatically
-
setUserEmail(
String email) → Future< void> - Set user email for pre-filling forms
-
setUserIdentifier(
String identifier) → Future< void> - Set a user identifier for tracking feedback
-
submitFeedback(
{required String title, required String description, String? category}) → Future< String> - Submit feedback programmatically
-
vote(
String feedbackId) → Future< int> - Vote on a feedback item